@@ -1,18 +1,16 @@
-# $Id: v10_4.pm,v 1.4 2008/11/05 22:52:35 drhyde Exp $
-
-package Devel::AssertOS::MacOSX::v10_4;
+package Devel::AssertOS::MacOSX::v10_9;
 
 use Devel::CheckOS;
+use strict;
 
-use Devel::AssertOS::MacOSX;
-
-$VERSION = '1.2';
+our $VERSION = '1.0';
 
 sub os_is {
-    `sw_vers -productVersion` =~ /^10\.4\./ ? 1 : 0;
+    Devel::CheckOS::os_is('MacOSX') &&
+    `sw_vers -productVersion` =~ /^10\.9\./ ? 1 : 0;
 }
 
-sub expn { "The operating system is some version of OS X Tiger (10.4)" }
+sub expn { "The operating system is some version of OS X Mavericks (10.9)" }
 
 Devel::CheckOS::die_unsupported() unless(os_is());
 
@@ -25,3 +23,4 @@ This software is free-as-in-speech software, and may be used, distributed, and m
 =cut
 
 1;
+
